;;;************************************************************
;;; Filename: RegistrySubKeys.LSP
;;; Author:   David M. Stein
;;; Date:     3/2/02
;;; Purpose:  Demonstrates use of (vl-registry-descendents)
;;;           function within a recursive function to perform
;;;           exhaustive search of sub-keys.
;;;************************************************************

(defun RegistrySubKeys (regkey indent / vs ks)
	(if (equal "\\" (substr regkey (strlen regkey)))
  	(setq regkey (substr regkey 1 (1- (strlen regkey))))
	)

	(or indent (setq indent ""))

  (princ (strcat indent "Key: " regkey "\n"))

	(if (setq vs (vl-registry-descendents regkey t))	; value names
    (progn
      (princ indent)
      (princ "- values:\n")
      (foreach v (vl-sort vs '<)
				(princ indent)
				(princ (strcat "  " (if (equal v "") "@" v) ": " ) )
				(prin1 (vl-registry-read regkey v))
				(terpri)
			)
		)
    (progn
      (princ indent)
      (princ "- no values\n")
    )
  )
  (if (setq ks (vl-registry-descendents regkey))		; subkey names
    (progn
      (princ indent)
      (princ "- subkeys:\n")
      (setq regkey (strcat regkey "\\")
	    			indent (strcat indent "  ")
			)
      (foreach k (vl-sort ks '<)
				(RegistrySubKeys (strcat regkey k) indent)
			)
		)
    (progn
      (princ indent)
      (princ "- no subkeys\n")
    )
  )
	(cons (length ks) (length vs))
)

(princ)