;;;************************************************************
;;; Filename: Toolbars.LSP
;;; Author:   David M. Stein
;;; Date:     5/20/02
;;; Purpose:  Demonstrates use of toolbar object functions.
;;;************************************************************

(defun get-item (collection item / result)
	(if
		(not
			(vl-catch-all-error-p
				(setq result
					(vl-catch-all-apply 'vla-item (list collection item))
				)
			)
		)
		result
	)
)

(defun get-MenuGroups ()
	(vla-get-menugroups (vlax-get-acad-object))
)

(defun get-MenuGroup (name)
  (if (menugroup name)
    (get-item (get-MenuGroups) name)
  ) 
)

(defun get-Toolbars (mgroup / mg result)
  (if (setq mg (get-MenuGroup mgroup))
    (progn
      (setq result (vla-get-Toolbars mg))
      (vlax-release-object mg)
     )
   )
  result
)

(defun get-Toolbar (mgroup name / tbs result)
  (if (setq tbs (get-Toolbars mgroup))
    (progn
      (setq result (get-item tbs name))
      (vlax-release-object tbs)
    )
  )
  result
)

(defun Toolbar-AddButton
  (tb name macro bitmap1 tagstring helpstring / newButton index)
  (setq index (vla-get-Count tb))
  (cond
    ( (setq newButton 
        (vla-AddToolbarButton tb
          (vlax-make-variant index vlax-vbInteger)
          name helpstring macro
        )
      )
      (vla-put-TagString newButton tagstring)
      (vla-SetBitMaps newButton bitmap1 bitmap1)
      newButton
    )
  )
)

(defun Toolbar-Float (mgroup name top left rows)
  (if (setq tb (get-Toolbar mgroup name))
    (if (= (vla-get-Visible tb) :vlax-True)
      (progn
        (vla-Float tb top left rows)
        (vlax-release-object tb)
        1 ;; float and visible
      )
      -1 ;; toolbar not visible
    )
    0 ;; toolbar not found
  )
)

(defun Toolbar-Dock (mgroup name side / tb loc)
  (cond
    ( (= (strcase side) "LEFT")  (setq loc acToolbarDockLeft))
    ( (= (strcase side) "RIGHT") (setq loc acToolbarDockRight))
    ( (= (strcase side) "TOP")   (setq loc acToolbarDockTop))
    ( (= (strcase side) "BOTTOM")(setq loc acToolbarDockBottom))
    ( T (setq loc acToolbarDockLeft))
  )
  (if (setq tb (get-Toolbar mgroup name))
    (progn
      (vla-Dock tb loc)
      (vlax-release-object tb)
    )
    (princ (strcat "\nToolbar (" name ") not found."))
  )
)

(defun Toolbar-Make ( / tb)
  (cond
    ( (setq tb (vla-add (get-toolbars "acad") "MyToolbar"))
      ;(Toolbar-Float "acad" "MyToolbar" 200 200 1)
      (if (Toolbar-AddButton tb 
        "Line" "\003\003\020\nLine" 
        "ICON_16_LINE" "MyButton001" "Draws a line: LINE"
        )
        (alert "I just added a button to my toolbar!")
				(alert "Uh oh! ...")
      )
		  (vlax-release-object tb)
    )
  )
)

(princ)